@@ -21,7 +21,7 @@ class PortfolioInfo:
 
     def get_all_portfolio(self):
         return pd.read_sql(f"""  
-            select t1."portfolioCycleId",t1.username,t1.symbol,COALESCE("latestMatchPrice",0) as "latestMatchPrice",
+            select t1."portfolioCycleId",t4."tradingModel",t4."portfolioModel",t1.username,t1.symbol,COALESCE("latestMatchPrice",0) as "latestMatchPrice",
                 "totalAmount",CASE WHEN "forceSellAmount" > "availableAmount" THEN 0 ELSE "availableAmount" - "forceSellAmount"  END as "availableAmount",
                 "pendingAmount","scheduledAmount", "averageMatchedPrice","targetPercent",
                 "balance","initBalance", t4."cutoffDate", t4."startDate",t4."endDate", "forceSellAmount" , t1."portfolioType"
